==> gprolog-1.4.0.tar.gz: gprolog-1.4.0/src/W32GUICons/w32_resource.h <==
#ifndef IDC_STATIC
#define IDC_STATIC (-1)
#endif

#define IDR_MENU                                102
#define IDR_ACCEL                               106
#define IDD_STACK_SIZES                         109
#define IDC_STACK_DESC0                         1000
#define IDC_STACK_DESC1                         1001
#define IDC_DEF_SZ1                             1002
#define IDC_ENV_VAR_NAME1                       1003
#define IDC_DEF_SZ0                             1004
#define IDC_ENV_SZ0                             1005
#define IDC_ENV_SZ1                             1006
#define IDC_ENV_VAR_NAME0                       1007
#define IDC_REG_SZ1                             1008
#define IDC_CUR_SZ0                             1010
#define IDM_STACK_SIZES                         40000
#define IDM_CONSULT                             40001
#define IDM_CHDIR                               40002
#define IDM_FILE_NAME                           40003
#define IDM_EXIT                                40004
#define IDM_COPY                                40005
#define IDM_PASTE                               40006
#define IDM_SELECT_ALL                          40007
#define IDM_COPY_ON_SEL                         40009
#define IDM_SAVE_OPTIONS                        40011
#define IDM_INTERRUPT                           40012
#define IDM_BEEP                                40013
#define IDM_WRAP                                40014
#define IDM_BUFFERING                           40015
#define IDM_FLUSH                               40016
#define IDM_SHOW_CONSOLE                        40018
#define IDM_FONT                                40019
#define IDM_MANUAL                              40020
#define IDM_INDEX                               40021
#define IDM_WEB                                 40022
#define IDM_ABOUT                               40023
#define IDC_REG_SZ0                             40026
#define IDC_STACK_DESC2                         40027
#define IDC_DEF_SZ2                             40028
#define IDC_ENV_VAR_NAME2                       40029
#define IDC_ENV_SZ2                             40030
#define IDC_REG_SZ2                             40031
#define IDC_STACK_DESC3                         40032
#define IDC_DEF_SZ3                             40033
#define IDC_ENV_VAR_NAME3                       40034
#define IDC_ENV_SZ3                             40035
#define IDC_REG_SZ3                             40036
#define IDC_CUR_SZ1                             40037
#define IDC_CUR_SZ2                             40038
#define IDC_CUR_SZ3                             40039
#define IDC_FIXED_SIZES                         40040

==> gprolog_1.4.5.orig.tar.gz: gprolog-1.4.5/src/W32GUICons/w32_resource.h <==
#ifndef IDC_STATIC
#define IDC_STATIC (-1)
#endif

#define IDR_MENU                                102
#define IDR_ACCEL                               106
#define IDD_STACK_SIZES                         109
#define IDI_ICON                                113
#define IDC_STACK_DESC0                         1000
#define IDC_STACK_DESC1                         1001
#define IDC_DEF_SZ1                             1002
#define IDC_ENV_VAR_NAME1                       1003
#define IDC_DEF_SZ0                             1004
#define IDC_ENV_SZ0                             1005
#define IDC_ENV_SZ1                             1006
#define IDC_ENV_VAR_NAME0                       1007
#define IDC_REG_SZ1                             1008
#define IDC_CUR_SZ0                             1010
#define IDM_STACK_SIZES                         40000
#define IDM_CONSULT                             40001
#define IDM_CHDIR                               40002
#define IDM_FILE_NAME                           40003
#define IDM_EXIT                                40004
#define IDM_COPY                                40005
#define IDM_PASTE                               40006
#define IDM_SELECT_ALL                          40007
#define IDM_COPY_ON_SEL                         40009
#define IDM_SAVE_OPTIONS                        40011
#define IDM_INTERRUPT                           40012
#define IDM_BEEP                                40013
#define IDM_WRAP                                40014
#define IDM_BUFFERING                           40015
#define IDM_FLUSH                               40016
#define IDM_SHOW_CONSOLE                        40018
#define IDM_FONT                                40019
#define IDM_MANUAL                              40020
#define IDM_INDEX                               40021
#define IDM_WEB                                 40022
#define IDM_ABOUT                               40023
#define IDC_REG_SZ0                             40026
#define IDC_STACK_DESC2                         40027
#define IDC_DEF_SZ2                             40028
#define IDC_ENV_VAR_NAME2                       40029
#define IDC_ENV_SZ2                             40030
#define IDC_REG_SZ2                             40031
#define IDC_STACK_DESC3                         40032
#define IDC_DEF_SZ3                             40033
#define IDC_ENV_VAR_NAME3                       40034
#define IDC_ENV_SZ3                             40035
#define IDC_REG_SZ3                             40036
#define IDC_CUR_SZ1                             40037
#define IDC_CUR_SZ2                             40038
#define IDC_CUR_SZ3                             40039
#define IDC_FIXED_SIZES                         40040
#define IDC_STACK_DESC4                         40041
#define IDC_DEF_SZ4                             40042
#define IDC_ENV_VAR_NAME4                       40043
#define IDC_ENV_SZ4                             40044
#define IDC_REG_SZ4                             40045
#define IDC_CUR_SZ4                             40046
